import { EventEmitter, Type, PipeTransform } from '@angular/core';
import { FieldType, FilterMode } from './gridview-enums';
import { SortDirection } from '../shared';
import { IGridViewCellTemplateComponent, IGridViewFilterCellTemplateComponent } from './gridview-interfaces';
export declare class ColumnBase {
    caption: string;
    visible: boolean;
    printVisible: boolean;
    width: string;
    printWidth: string;
    name: string;
    columnIndex: number;
    allowSizing: boolean;
    getRowCellClass: (row: any) => string;
    getRowCellStyle: (row: any) => any;
    render: (row: any) => string;
    dataChanged: EventEmitter<any[]>;
    customProps: {
        [name: string]: any;
    };
    constructor(caption?: string);
    getIdentifier(): string;
}
export declare class DataColumn extends ColumnBase {
    fieldName: string;
    caption: string;
    fieldType: FieldType;
    columnPipe: ColumnPipe;
    sortIndex: number;
    filterValue: any;
    format: string;
    sortable: boolean;
    disableWrapping: boolean;
    filterMode: FilterMode;
    template: Type<IGridViewCellTemplateComponent>;
    editTemplate: Type<IGridViewCellTemplateComponent>;
    templateInit: EventEmitter<IGridViewCellTemplateComponent>;
    filterTemplate: Type<IGridViewFilterCellTemplateComponent>;
    filterDelayMilliseconds: number;
    sortDirection: SortDirection;
    customSort: (obj1: any, obj2: any) => number;
    customFilter: (obj: any) => boolean;
    required: boolean;
    readonly: boolean;
    private _filterOptions;
    filterOptions: any[];
    filterOptionsChanged: EventEmitter<any>;
    constructor(fieldName?: string, caption?: string);
    getCaption(): string;
    getIdentifier(): string;
    setSortDirection(sortDirection: SortDirection): DataColumn;
    setFilterMode(filterMode: FilterMode): DataColumn;
    setName(name: string): DataColumn;
    setWidth(width: string): DataColumn;
    setFieldType(fieldType: FieldType): DataColumn;
    setSortable(): DataColumn;
    setRequired(): DataColumn;
    setReadOnly(): DataColumn;
}
export declare class NumericColumn extends DataColumn {
    fieldName: string;
    caption: string;
    decimalPlaces: number;
    constructor(fieldName?: string, caption?: string);
}
export declare class ButtonColumn extends DataColumn {
    fieldName: string;
    caption: string;
    click: EventEmitter<any>;
    text: string;
    class: string;
    constructor(fieldName?: string, caption?: string);
}
export declare class ColumnPipe {
    pipe: PipeTransform;
    args: any;
    constructor(pipe: PipeTransform, args?: any);
}
export declare class TextAreaColumn extends DataColumn {
    rows: number;
}
export declare class SelectColumn extends DataColumn {
    selectOptions: Array<any>;
    displayMember: string;
    valueMember: string;
    parentField: string;
    addBlank: boolean;
}
