import { EventEmitter, Type } from '@angular/core';
import { Observable } from 'rxjs';
import { ColumnBase, DataColumn } from './gridview-columns';
import { SelectMode, PagingType, PrintOrientation } from './gridview-enums';
import { IGridViewRowTemplateComponent, IGridViewComponent } from './gridview-interfaces';
import { SortDirection } from '../shared';
export declare const TEMP_KEY_FIELD: string;
export declare class GridView {
    private _data;
    pageSize: number;
    currentPage: number;
    totalRecords: number;
    columns: Array<ColumnBase>;
    showHeader: boolean;
    allowRowSelect: boolean;
    visible: boolean;
    detailGridView: DetailGridView;
    keyFieldName: string;
    descriptionField: string;
    selectMode: SelectMode;
    disableAutoSort: boolean;
    disableAutoFilter: boolean;
    pagingType: PagingType;
    height: string;
    width: string;
    dataChanged: EventEmitter<any>;
    rowEdit: EventEmitter<RowArguments>;
    rowCancelled: EventEmitter<RowArguments>;
    rowSave: EventEmitter<RowArguments>;
    rowSaveAll: EventEmitter<RowArguments>;
    rowCreate: EventEmitter<RowArguments>;
    rowDelete: EventEmitter<RowArguments>;
    cellValueChanged: EventEmitter<CellArguments>;
    rowInvalidated: EventEmitter<DataColumn[]>;
    rowTemplate: Type<IGridViewRowTemplateComponent>;
    customProps: {
        [name: string]: any;
    };
    customEvents: any;
    filterVisible: boolean;
    disableFilterRow: boolean;
    loading: boolean;
    showNoResults: boolean;
    allowColumnOrdering: boolean;
    allowColumnCustomization: boolean;
    saveGridStateToStorage: boolean;
    gridStateVersion: number;
    allowAdd: boolean;
    allowEdit: boolean;
    allowDelete: boolean;
    autoPopulateColumns: boolean;
    allowMultiEdit: boolean;
    noBorder: boolean;
    inRowPromptConfirm: boolean;
    name: string;
    timezone: string;
    gridViewComponent: IGridViewComponent;
    getRowClass: (row: any) => string;
    printing: boolean;
    printSettings: PrintSettings;
    getDataColumns(): Array<DataColumn>;
    getVisibleColumns(hideRowTemplate?: boolean): Array<ColumnBase>;
    getDistinctValues(column: DataColumn): any[];
    setFilterOptions(): void;
    refreshData(): void;
    data: Array<any>;
    private _stateLoaded;
    private _defaultState;
    loadGridState(): boolean;
    private getFieldName(obj, currField);
    populateColumns(): void;
    saveGridState(): void;
    resetGridState(): void;
    setTempKeyField(): void;
    private populateTempKey();
    private getGridState();
    private setGridState(state);
    addRow(): void;
    printGrid(): void;
}
export declare class DetailGridView extends GridView {
    getChildData: (parent: any) => Observable<Array<any>>;
    parentRow: any;
    hideExpandButton: boolean;
    createInstance(parentRow: any): DetailGridView;
}
export declare class GridState {
    gridColumnStates: Array<GridColumnState>;
    currentPage: number;
    pageSize: number;
    filterVisible: boolean;
}
export declare class GridColumnState {
    identifier: string;
    width: string;
    sortDirection: SortDirection;
    sortIndex: number;
    columnIndex: number;
    filterValue: any;
    visible: boolean;
}
export declare class RowArguments {
    grid: GridView;
    rows: any[];
    deletedRows: any[];
    cancel: boolean;
    observable: Observable<any>;
    readonly row: any;
}
export declare class CellArguments {
    parentGridView: GridView;
    row: any;
    column: ColumnBase;
}
export declare class PrintSettings {
    orientation: PrintOrientation;
    fontSize: string;
    cellPadding: string;
}
