import { Http, RequestOptions } from '@angular/http';
import { SortDirection } from '../shared';
import { Observable } from 'rxjs';
export declare class DataService {
    protected http: Http;
    constructor(http: Http);
    getOptions(): RequestOptions;
    post<TIn, TOut>(url: string, body?: TIn): Observable<TOut>;
    put<TIn, TOut>(url: string, body: TIn): Observable<TOut>;
    delete(url: string): Observable<boolean>;
    getItems<TObject>(url: string, args?: GetArguments): Observable<Items<TObject>>;
    get<TObject>(url: string, args?: GetArguments): Observable<TObject>;
    handleError(error: any): Observable<never>;
}
export declare class Items<TObject> {
    data: TObject[];
    items: TObject[];
    count: number;
}
export declare class GetArguments {
    params: {
        [paramName: string]: string;
    };
}
export declare class OrderBy {
    sortField: string;
    sortDirection: SortDirection;
    constructor(sortField: string, sortDirection?: SortDirection);
}
export declare abstract class FilterBase {
    abstract getFilterString(): string;
}
export declare class FilterGroup extends FilterBase {
    filterOperator: FilterOperator;
    operator: FilterOperator;
    filters: Array<FilterBase>;
    constructor(filterOperator?: FilterOperator);
    getFilterString(): string;
}
export declare class BinaryFilter extends FilterBase {
    fieldName: string;
    filterValue: any;
    filterType: FilterType;
    constructor(fieldName: string, filterValue: any, filterType?: FilterType);
    getFilterString(): string;
}
export declare enum FilterType {
    EqualTo = 0,
    NotEqualTo = 1,
    LessThan = 2,
    GreaterThan = 3,
    LessThanOrEqual = 4,
    GreaterThanOrEqual = 5,
    Contains = 6,
    StartsWith = 7,
    EndsWith = 8,
}
export declare enum FilterOperator {
    And = 0,
    Or = 1,
}
